from . import dream3dreview

def adaptive_alignment(data_container_array, global_correction = None, input_path = None, shift_x = None, shift_y = None, image_data_array_path = None, new_cell_array_name = None, min_radius = None, max_radius = None, number_circles = None, observer = None) -> int:
  """Pythonic interface to AdaptiveAlignment Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    global_correction (int): Sets the "GlobalCorrection" filter property
    input_path (QString): Sets the "InputPath" filter property
    shift_x (float): Sets the "ShiftX" filter property
    shift_y (float): Sets the "ShiftY" filter property
    image_data_array_path (DataArrayPath): Sets the "ImageDataArrayPath" filter property
    new_cell_array_name (QString): Sets the "NewCellArrayName" filter property
    min_radius (float): Sets the "MinRadius" filter property
    max_radius (float): Sets the "MaxRadius" filter property
    number_circles (int): Sets the "NumberCircles" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.AdaptiveAlignment()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if global_correction is not None:
    filter.GlobalCorrection = global_correction
  if input_path is not None:
    filter.InputPath = input_path
  if shift_x is not None:
    filter.ShiftX = shift_x
  if shift_y is not None:
    filter.ShiftY = shift_y
  if image_data_array_path is not None:
    filter.ImageDataArrayPath = image_data_array_path
  if new_cell_array_name is not None:
    filter.NewCellArrayName = new_cell_array_name
  if min_radius is not None:
    filter.MinRadius = min_radius
  if max_radius is not None:
    filter.MaxRadius = max_radius
  if number_circles is not None:
    filter.NumberCircles = number_circles
  filter.execute()
  return filter.ErrorCode

def apply_transformation_to_geometry(data_container_array, manual_transformation_matrix = None, computed_transformation_matrix = None, geometry_to_transform = None, transformation_matrix_type = None, rotation_axis = None, rotation_angle = None, translation = None, scale = None, observer = None) -> int:
  """Pythonic interface to ApplyTransformationToGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    manual_transformation_matrix (DynamicTableData): Sets the "ManualTransformationMatrix" filter property
    computed_transformation_matrix (DataArrayPath): Sets the "ComputedTransformationMatrix" filter property
    geometry_to_transform (DataArrayPath): Sets the "GeometryToTransform" filter property
    transformation_matrix_type (int): Sets the "TransformationMatrixType" filter property
    rotation_axis (FloatVec3Type): Sets the "RotationAxis" filter property
    rotation_angle (float): Sets the "RotationAngle" filter property
    translation (FloatVec3Type): Sets the "Translation" filter property
    scale (FloatVec3Type): Sets the "Scale" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ApplyTransformationToGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if manual_transformation_matrix is not None:
    filter.ManualTransformationMatrix = manual_transformation_matrix
  if computed_transformation_matrix is not None:
    filter.ComputedTransformationMatrix = computed_transformation_matrix
  if geometry_to_transform is not None:
    filter.GeometryToTransform = geometry_to_transform
  if transformation_matrix_type is not None:
    filter.TransformationMatrixType = transformation_matrix_type
  if rotation_axis is not None:
    filter.RotationAxis = rotation_axis
  if rotation_angle is not None:
    filter.RotationAngle = rotation_angle
  if translation is not None:
    filter.Translation = translation
  if scale is not None:
    filter.Scale = scale
  filter.execute()
  return filter.ErrorCode

def average_edge_face_cell_array_to_vertex_array(data_container_array, selected_array_path = None, average_vertex_array_path = None, observer = None) -> int:
  """Pythonic interface to AverageEdgeFaceCellArrayToVertexArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    average_vertex_array_path (DataArrayPath): Sets the "AverageVertexArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.AverageEdgeFaceCellArrayToVertexArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if average_vertex_array_path is not None:
    filter.AverageVertexArrayPath = average_vertex_array_path
  filter.execute()
  return filter.ErrorCode

def average_vertex_array_to_edge_face_cell_array(data_container_array, selected_array_path = None, average_cell_array_path = None, weighted_average = None, observer = None) -> int:
  """Pythonic interface to AverageVertexArrayToEdgeFaceCellArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    average_cell_array_path (DataArrayPath): Sets the "AverageCellArrayPath" filter property
    weighted_average (bool): Sets the "WeightedAverage" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.AverageVertexArrayToEdgeFaceCellArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if average_cell_array_path is not None:
    filter.AverageCellArrayPath = average_cell_array_path
  if weighted_average is not None:
    filter.WeightedAverage = weighted_average
  filter.execute()
  return filter.ErrorCode

def compute_umeyama_transform(data_container_array, source_point_set = None, dest_point_set = None, use_scaling = None, transformation_attribute_matrix_name = None, transformation_matrix_name = None, observer = None) -> int:
  """Pythonic interface to ComputeUmeyamaTransform Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    source_point_set (DataArrayPath): Sets the "SourcePointSet" filter property
    dest_point_set (DataArrayPath): Sets the "DestPointSet" filter property
    use_scaling (bool): Sets the "UseScaling" filter property
    transformation_attribute_matrix_name (QString): Sets the "TransformationAttributeMatrixName" filter property
    transformation_matrix_name (QString): Sets the "TransformationMatrixName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ComputeUmeyamaTransform()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if source_point_set is not None:
    filter.SourcePointSet = source_point_set
  if dest_point_set is not None:
    filter.DestPointSet = dest_point_set
  if use_scaling is not None:
    filter.UseScaling = use_scaling
  if transformation_attribute_matrix_name is not None:
    filter.TransformationAttributeMatrixName = transformation_attribute_matrix_name
  if transformation_matrix_name is not None:
    filter.TransformationMatrixName = transformation_matrix_name
  filter.execute()
  return filter.ErrorCode

def establish_foam_morphology(data_container_array, data_container_name = None, output_cell_attribute_matrix_path = None, input_cell_feature_ids_array_path = None, output_cell_ensemble_attribute_matrix_name = None, output_cell_feature_attribute_matrix_name = None, feature_ids_array_name = None, mask_array_name = None, cell_phases_array_name = None, num_features_array_name = None, qp_euclidean_distances_array_name = None, tj_euclidean_distances_array_name = None, gb_euclidean_distances_array_name = None, input_stats_array_path = None, input_phase_types_array_path = None, input_phase_names_array_path = None, input_shape_types_array_path = None, csv_output_file = None, periodic_boundaries = None, write_goal_attributes = None, have_features = None, min_strut_thickness = None, strut_thickness_variability = None, strut_shape_variability = None, smooth_struts = None, observer = None) -> int:
  """Pythonic interface to EstablishFoamMorphology Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    output_cell_attribute_matrix_path (DataArrayPath): Sets the "OutputCellAttributeMatrixPath" filter property
    input_cell_feature_ids_array_path (DataArrayPath): Sets the "InputCellFeatureIdsArrayPath" filter property
    output_cell_ensemble_attribute_matrix_name (QString): Sets the "OutputCellEnsembleAttributeMatrixName" filter property
    output_cell_feature_attribute_matrix_name (QString): Sets the "OutputCellFeatureAttributeMatrixName" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    mask_array_name (QString): Sets the "MaskArrayName" filter property
    cell_phases_array_name (QString): Sets the "CellPhasesArrayName" filter property
    num_features_array_name (QString): Sets the "NumFeaturesArrayName" filter property
    qp_euclidean_distances_array_name (QString): Sets the "QPEuclideanDistancesArrayName" filter property
    tj_euclidean_distances_array_name (QString): Sets the "TJEuclideanDistancesArrayName" filter property
    gb_euclidean_distances_array_name (QString): Sets the "GBEuclideanDistancesArrayName" filter property
    input_stats_array_path (DataArrayPath): Sets the "InputStatsArrayPath" filter property
    input_phase_types_array_path (DataArrayPath): Sets the "InputPhaseTypesArrayPath" filter property
    input_phase_names_array_path (DataArrayPath): Sets the "InputPhaseNamesArrayPath" filter property
    input_shape_types_array_path (DataArrayPath): Sets the "InputShapeTypesArrayPath" filter property
    csv_output_file (QString): Sets the "CsvOutputFile" filter property
    periodic_boundaries (bool): Sets the "PeriodicBoundaries" filter property
    write_goal_attributes (bool): Sets the "WriteGoalAttributes" filter property
    have_features (int): Sets the "HaveFeatures" filter property
    min_strut_thickness (double): Sets the "MinStrutThickness" filter property
    strut_thickness_variability (float): Sets the "StrutThicknessVariability" filter property
    strut_shape_variability (float): Sets the "StrutShapeVariability" filter property
    smooth_struts (bool): Sets the "SmoothStruts" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.EstablishFoamMorphology()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if output_cell_attribute_matrix_path is not None:
    filter.OutputCellAttributeMatrixPath = output_cell_attribute_matrix_path
  if input_cell_feature_ids_array_path is not None:
    filter.InputCellFeatureIdsArrayPath = input_cell_feature_ids_array_path
  if output_cell_ensemble_attribute_matrix_name is not None:
    filter.OutputCellEnsembleAttributeMatrixName = output_cell_ensemble_attribute_matrix_name
  if output_cell_feature_attribute_matrix_name is not None:
    filter.OutputCellFeatureAttributeMatrixName = output_cell_feature_attribute_matrix_name
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if mask_array_name is not None:
    filter.MaskArrayName = mask_array_name
  if cell_phases_array_name is not None:
    filter.CellPhasesArrayName = cell_phases_array_name
  if num_features_array_name is not None:
    filter.NumFeaturesArrayName = num_features_array_name
  if qp_euclidean_distances_array_name is not None:
    filter.QPEuclideanDistancesArrayName = qp_euclidean_distances_array_name
  if tj_euclidean_distances_array_name is not None:
    filter.TJEuclideanDistancesArrayName = tj_euclidean_distances_array_name
  if gb_euclidean_distances_array_name is not None:
    filter.GBEuclideanDistancesArrayName = gb_euclidean_distances_array_name
  if input_stats_array_path is not None:
    filter.InputStatsArrayPath = input_stats_array_path
  if input_phase_types_array_path is not None:
    filter.InputPhaseTypesArrayPath = input_phase_types_array_path
  if input_phase_names_array_path is not None:
    filter.InputPhaseNamesArrayPath = input_phase_names_array_path
  if input_shape_types_array_path is not None:
    filter.InputShapeTypesArrayPath = input_shape_types_array_path
  if csv_output_file is not None:
    filter.CsvOutputFile = csv_output_file
  if periodic_boundaries is not None:
    filter.PeriodicBoundaries = periodic_boundaries
  if write_goal_attributes is not None:
    filter.WriteGoalAttributes = write_goal_attributes
  if have_features is not None:
    filter.HaveFeatures = have_features
  if min_strut_thickness is not None:
    filter.MinStrutThickness = min_strut_thickness
  if strut_thickness_variability is not None:
    filter.StrutThicknessVariability = strut_thickness_variability
  if strut_shape_variability is not None:
    filter.StrutShapeVariability = strut_shape_variability
  if smooth_struts is not None:
    filter.SmoothStruts = smooth_struts
  filter.execute()
  return filter.ErrorCode

def decimate_point_cloud(data_container_array, observer = None) -> int:
  """Pythonic interface to DecimatePointCloud Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.DecimatePointCloud()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def dbscan(data_container_array, selected_array_path = None, use_mask = None, mask_array_path = None, feature_ids_array_name = None, feature_attribute_matrix_name = None, epsilon = None, min_pnts = None, distance_metric = None, observer = None) -> int:
  """Pythonic interface to DBSCAN Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    feature_attribute_matrix_name (QString): Sets the "FeatureAttributeMatrixName" filter property
    epsilon (float): Sets the "Epsilon" filter property
    min_pnts (int): Sets the "MinPnts" filter property
    distance_metric (int): Sets the "DistanceMetric" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.DBSCAN()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if feature_attribute_matrix_name is not None:
    filter.FeatureAttributeMatrixName = feature_attribute_matrix_name
  if epsilon is not None:
    filter.Epsilon = epsilon
  if min_pnts is not None:
    filter.MinPnts = min_pnts
  if distance_metric is not None:
    filter.DistanceMetric = distance_metric
  filter.execute()
  return filter.ErrorCode

def downsample_vertex_geometry(data_container_array, vertex_attr_mat_path = None, downsample_type = None, decimation_freq = None, decimation_fraction = None, grid_resolution = None, observer = None) -> int:
  """Pythonic interface to DownsampleVertexGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    vertex_attr_mat_path (DataArrayPath): Sets the "VertexAttrMatPath" filter property
    downsample_type (int): Sets the "DownsampleType" filter property
    decimation_freq (int): Sets the "DecimationFreq" filter property
    decimation_fraction (float): Sets the "DecimationFraction" filter property
    grid_resolution (FloatVec3Type): Sets the "GridResolution" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.DownsampleVertexGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if vertex_attr_mat_path is not None:
    filter.VertexAttrMatPath = vertex_attr_mat_path
  if downsample_type is not None:
    filter.DownsampleType = downsample_type
  if decimation_freq is not None:
    filter.DecimationFreq = decimation_freq
  if decimation_fraction is not None:
    filter.DecimationFraction = decimation_fraction
  if grid_resolution is not None:
    filter.GridResolution = grid_resolution
  filter.execute()
  return filter.ErrorCode

def extract_internal_surfaces_from_triangle_geometry(data_container_array, triangle_data_container_name = None, node_types_array_path = None, internal_triangles_name = None, observer = None) -> int:
  """Pythonic interface to ExtractInternalSurfacesFromTriangleGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    triangle_data_container_name (DataArrayPath): Sets the "TriangleDataContainerName" filter property
    node_types_array_path (DataArrayPath): Sets the "NodeTypesArrayPath" filter property
    internal_triangles_name (QString): Sets the "InternalTrianglesName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ExtractInternalSurfacesFromTriangleGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if triangle_data_container_name is not None:
    filter.TriangleDataContainerName = triangle_data_container_name
  if node_types_array_path is not None:
    filter.NodeTypesArrayPath = node_types_array_path
  if internal_triangles_name is not None:
    filter.InternalTrianglesName = internal_triangles_name
  filter.execute()
  return filter.ErrorCode

def find_array_statistics(data_container_array, find_histogram = None, find_length = None, find_min = None, find_max = None, find_mean = None, find_median = None, find_std_deviation = None, find_summation = None, use_mask = None, standardize_data = None, compute_by_index = None, destination_attribute_matrix = None, mask_array_path = None, length_array_name = None, minimum_array_name = None, maximum_array_name = None, mean_array_name = None, median_array_name = None, std_deviation_array_name = None, summation_array_name = None, standardized_array_name = None, selected_array_path = None, feature_ids_array_path = None, histogram_array_name = None, use_full_range = None, num_bins = None, min_range = None, max_range = None, observer = None) -> int:
  """Pythonic interface to FindArrayStatistics Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    find_histogram (bool): Sets the "FindHistogram" filter property
    find_length (bool): Sets the "FindLength" filter property
    find_min (bool): Sets the "FindMin" filter property
    find_max (bool): Sets the "FindMax" filter property
    find_mean (bool): Sets the "FindMean" filter property
    find_median (bool): Sets the "FindMedian" filter property
    find_std_deviation (bool): Sets the "FindStdDeviation" filter property
    find_summation (bool): Sets the "FindSummation" filter property
    use_mask (bool): Sets the "UseMask" filter property
    standardize_data (bool): Sets the "StandardizeData" filter property
    compute_by_index (bool): Sets the "ComputeByIndex" filter property
    destination_attribute_matrix (DataArrayPath): Sets the "DestinationAttributeMatrix" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    length_array_name (QString): Sets the "LengthArrayName" filter property
    minimum_array_name (QString): Sets the "MinimumArrayName" filter property
    maximum_array_name (QString): Sets the "MaximumArrayName" filter property
    mean_array_name (QString): Sets the "MeanArrayName" filter property
    median_array_name (QString): Sets the "MedianArrayName" filter property
    std_deviation_array_name (QString): Sets the "StdDeviationArrayName" filter property
    summation_array_name (QString): Sets the "SummationArrayName" filter property
    standardized_array_name (QString): Sets the "StandardizedArrayName" filter property
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    histogram_array_name (QString): Sets the "HistogramArrayName" filter property
    use_full_range (bool): Sets the "UseFullRange" filter property
    num_bins (int32_t): Sets the "NumBins" filter property
    min_range (float): Sets the "MinRange" filter property
    max_range (float): Sets the "MaxRange" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.FindArrayStatistics()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if find_histogram is not None:
    filter.FindHistogram = find_histogram
  if find_length is not None:
    filter.FindLength = find_length
  if find_min is not None:
    filter.FindMin = find_min
  if find_max is not None:
    filter.FindMax = find_max
  if find_mean is not None:
    filter.FindMean = find_mean
  if find_median is not None:
    filter.FindMedian = find_median
  if find_std_deviation is not None:
    filter.FindStdDeviation = find_std_deviation
  if find_summation is not None:
    filter.FindSummation = find_summation
  if use_mask is not None:
    filter.UseMask = use_mask
  if standardize_data is not None:
    filter.StandardizeData = standardize_data
  if compute_by_index is not None:
    filter.ComputeByIndex = compute_by_index
  if destination_attribute_matrix is not None:
    filter.DestinationAttributeMatrix = destination_attribute_matrix
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if length_array_name is not None:
    filter.LengthArrayName = length_array_name
  if minimum_array_name is not None:
    filter.MinimumArrayName = minimum_array_name
  if maximum_array_name is not None:
    filter.MaximumArrayName = maximum_array_name
  if mean_array_name is not None:
    filter.MeanArrayName = mean_array_name
  if median_array_name is not None:
    filter.MedianArrayName = median_array_name
  if std_deviation_array_name is not None:
    filter.StdDeviationArrayName = std_deviation_array_name
  if summation_array_name is not None:
    filter.SummationArrayName = summation_array_name
  if standardized_array_name is not None:
    filter.StandardizedArrayName = standardized_array_name
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if histogram_array_name is not None:
    filter.HistogramArrayName = histogram_array_name
  if use_full_range is not None:
    filter.UseFullRange = use_full_range
  if num_bins is not None:
    filter.NumBins = num_bins
  if min_range is not None:
    filter.MinRange = min_range
  if max_range is not None:
    filter.MaxRange = max_range
  filter.execute()
  return filter.ErrorCode

def find_element_centroids(data_container_array, cell_centroids_array_path = None, create_vertex_data_container = None, new_data_container_name = None, vertex_attribute_matrix_name = None, observer = None) -> int:
  """Pythonic interface to FindElementCentroids Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_centroids_array_path (DataArrayPath): Sets the "CellCentroidsArrayPath" filter property
    create_vertex_data_container (bool): Sets the "CreateVertexDataContainer" filter property
    new_data_container_name (DataArrayPath): Sets the "NewDataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.FindElementCentroids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_centroids_array_path is not None:
    filter.CellCentroidsArrayPath = cell_centroids_array_path
  if create_vertex_data_container is not None:
    filter.CreateVertexDataContainer = create_vertex_data_container
  if new_data_container_name is not None:
    filter.NewDataContainerName = new_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  filter.execute()
  return filter.ErrorCode

def find_norm(data_container_array, selected_array_path = None, norm_array_path = None, p_space = None, observer = None) -> int:
  """Pythonic interface to FindNorm Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    norm_array_path (DataArrayPath): Sets the "NormArrayPath" filter property
    p_space (float): Sets the "PSpace" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.FindNorm()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if norm_array_path is not None:
    filter.NormArrayPath = norm_array_path
  if p_space is not None:
    filter.PSpace = p_space
  filter.execute()
  return filter.ErrorCode

def find_vertex_to_triangle_distances(data_container_array, vertex_data_container = None, triangle_data_container = None, triangle_normals_array_path = None, distances_array_path = None, closest_triangle_id_array_path = None, observer = None) -> int:
  """Pythonic interface to FindVertexToTriangleDistances Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    vertex_data_container (DataArrayPath): Sets the "VertexDataContainer" filter property
    triangle_data_container (DataArrayPath): Sets the "TriangleDataContainer" filter property
    triangle_normals_array_path (DataArrayPath): Sets the "TriangleNormalsArrayPath" filter property
    distances_array_path (DataArrayPath): Sets the "DistancesArrayPath" filter property
    closest_triangle_id_array_path (DataArrayPath): Sets the "ClosestTriangleIdArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.FindVertexToTriangleDistances()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if vertex_data_container is not None:
    filter.VertexDataContainer = vertex_data_container
  if triangle_data_container is not None:
    filter.TriangleDataContainer = triangle_data_container
  if triangle_normals_array_path is not None:
    filter.TriangleNormalsArrayPath = triangle_normals_array_path
  if distances_array_path is not None:
    filter.DistancesArrayPath = distances_array_path
  if closest_triangle_id_array_path is not None:
    filter.ClosestTriangleIdArrayPath = closest_triangle_id_array_path
  filter.execute()
  return filter.ErrorCode

def iterative_closest_point(data_container_array, moving_vertex_geometry = None, target_vertex_geometry = None, iterations = None, apply_transform = None, transform_attribute_matrix_name = None, transform_array_name = None, observer = None) -> int:
  """Pythonic interface to IterativeClosestPoint Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    moving_vertex_geometry (DataArrayPath): Sets the "MovingVertexGeometry" filter property
    target_vertex_geometry (DataArrayPath): Sets the "TargetVertexGeometry" filter property
    iterations (int): Sets the "Iterations" filter property
    apply_transform (bool): Sets the "ApplyTransform" filter property
    transform_attribute_matrix_name (QString): Sets the "TransformAttributeMatrixName" filter property
    transform_array_name (QString): Sets the "TransformArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.IterativeClosestPoint()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if moving_vertex_geometry is not None:
    filter.MovingVertexGeometry = moving_vertex_geometry
  if target_vertex_geometry is not None:
    filter.TargetVertexGeometry = target_vertex_geometry
  if iterations is not None:
    filter.Iterations = iterations
  if apply_transform is not None:
    filter.ApplyTransform = apply_transform
  if transform_attribute_matrix_name is not None:
    filter.TransformAttributeMatrixName = transform_attribute_matrix_name
  if transform_array_name is not None:
    filter.TransformArrayName = transform_array_name
  filter.execute()
  return filter.ErrorCode

def import_qm_meltpool_h5_file(data_container_array, input_files = None, data_container_path = None, vertex_attribute_matrix_name = None, slice_range = None, power = None, possible_indices = None, observer = None) -> int:
  """Pythonic interface to ImportQMMeltpoolH5File Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_files (VectString): Sets the "InputFiles" filter property
    data_container_path (DataArrayPath): Sets the "DataContainerPath" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    slice_range (IntVec2Type): Sets the "SliceRange" filter property
    power (float): Sets the "Power" filter property
    possible_indices (QString): Sets the "PossibleIndices" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ImportQMMeltpoolH5File()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_files is not None:
    filter.InputFiles = input_files
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if slice_range is not None:
    filter.SliceRange = slice_range
  if power is not None:
    filter.Power = power
  if possible_indices is not None:
    filter.PossibleIndices = possible_indices
  filter.execute()
  return filter.ErrorCode

def k_distance_graph(data_container_array, selected_array_path = None, use_mask = None, mask_array_path = None, k_distance_array_path = None, min_dist = None, distance_metric = None, observer = None) -> int:
  """Pythonic interface to KDistanceGraph Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    k_distance_array_path (DataArrayPath): Sets the "KDistanceArrayPath" filter property
    min_dist (int): Sets the "MinDist" filter property
    distance_metric (int): Sets the "DistanceMetric" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.KDistanceGraph()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if k_distance_array_path is not None:
    filter.KDistanceArrayPath = k_distance_array_path
  if min_dist is not None:
    filter.MinDist = min_dist
  if distance_metric is not None:
    filter.DistanceMetric = distance_metric
  filter.execute()
  return filter.ErrorCode

def k_means(data_container_array, selected_array_path = None, use_mask = None, mask_array_path = None, feature_ids_array_name = None, means_array_name = None, init_clusters = None, feature_attribute_matrix_name = None, distance_metric = None, observer = None) -> int:
  """Pythonic interface to KMeans Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    means_array_name (QString): Sets the "MeansArrayName" filter property
    init_clusters (int): Sets the "InitClusters" filter property
    feature_attribute_matrix_name (QString): Sets the "FeatureAttributeMatrixName" filter property
    distance_metric (int): Sets the "DistanceMetric" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.KMeans()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if means_array_name is not None:
    filter.MeansArrayName = means_array_name
  if init_clusters is not None:
    filter.InitClusters = init_clusters
  if feature_attribute_matrix_name is not None:
    filter.FeatureAttributeMatrixName = feature_attribute_matrix_name
  if distance_metric is not None:
    filter.DistanceMetric = distance_metric
  filter.execute()
  return filter.ErrorCode

def k_medoids(data_container_array, selected_array_path = None, use_mask = None, mask_array_path = None, feature_ids_array_name = None, medoids_array_name = None, feature_attribute_matrix_name = None, init_clusters = None, distance_metric = None, observer = None) -> int:
  """Pythonic interface to KMedoids Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    medoids_array_name (QString): Sets the "MedoidsArrayName" filter property
    feature_attribute_matrix_name (QString): Sets the "FeatureAttributeMatrixName" filter property
    init_clusters (int): Sets the "InitClusters" filter property
    distance_metric (int): Sets the "DistanceMetric" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.KMedoids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if medoids_array_name is not None:
    filter.MedoidsArrayName = medoids_array_name
  if feature_attribute_matrix_name is not None:
    filter.FeatureAttributeMatrixName = feature_attribute_matrix_name
  if init_clusters is not None:
    filter.InitClusters = init_clusters
  if distance_metric is not None:
    filter.DistanceMetric = distance_metric
  filter.execute()
  return filter.ErrorCode

def normalize_arrays(data_container_array, selected_data_array_paths = None, normalize_type = None, range_min = None, range_max = None, postfix = None, use_mask = None, mask_array_path = None, default_value = None, observer = None) -> int:
  """Pythonic interface to NormalizeArrays Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    normalize_type (int): Sets the "NormalizeType" filter property
    range_min (double): Sets the "RangeMin" filter property
    range_max (double): Sets the "RangeMax" filter property
    postfix (QString): Sets the "Postfix" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    default_value (double): Sets the "DefaultValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.NormalizeArrays()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  if normalize_type is not None:
    filter.NormalizeType = normalize_type
  if range_min is not None:
    filter.RangeMin = range_min
  if range_max is not None:
    filter.RangeMax = range_max
  if postfix is not None:
    filter.Postfix = postfix
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if default_value is not None:
    filter.DefaultValue = default_value
  filter.execute()
  return filter.ErrorCode

def point_sample_triangle_geometry(data_container_array, samples_number_type = None, triangle_geometry = None, vertex_geometry = None, vertex_attribute_matrix_name = None, number_of_samples = None, parent_geometry = None, triangle_areas_array_path = None, use_mask = None, mask_array_path = None, selected_data_array_paths = None, observer = None) -> int:
  """Pythonic interface to PointSampleTriangleGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    samples_number_type (int): Sets the "SamplesNumberType" filter property
    triangle_geometry (DataArrayPath): Sets the "TriangleGeometry" filter property
    vertex_geometry (QString): Sets the "VertexGeometry" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    number_of_samples (int): Sets the "NumberOfSamples" filter property
    parent_geometry (DataArrayPath): Sets the "ParentGeometry" filter property
    triangle_areas_array_path (DataArrayPath): Sets the "TriangleAreasArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.PointSampleTriangleGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if samples_number_type is not None:
    filter.SamplesNumberType = samples_number_type
  if triangle_geometry is not None:
    filter.TriangleGeometry = triangle_geometry
  if vertex_geometry is not None:
    filter.VertexGeometry = vertex_geometry
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if number_of_samples is not None:
    filter.NumberOfSamples = number_of_samples
  if parent_geometry is not None:
    filter.ParentGeometry = parent_geometry
  if triangle_areas_array_path is not None:
    filter.TriangleAreasArrayPath = triangle_areas_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  filter.execute()
  return filter.ErrorCode

def potts_model(data_container_array, iterations = None, temperature = None, periodic_boundaries = None, use_mask = None, feature_ids_array_path = None, mask_array_path = None, observer = None) -> int:
  """Pythonic interface to PottsModel Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    iterations (int): Sets the "Iterations" filter property
    temperature (double): Sets the "Temperature" filter property
    periodic_boundaries (bool): Sets the "PeriodicBoundaries" filter property
    use_mask (bool): Sets the "UseMask" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.PottsModel()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if iterations is not None:
    filter.Iterations = iterations
  if temperature is not None:
    filter.Temperature = temperature
  if periodic_boundaries is not None:
    filter.PeriodicBoundaries = periodic_boundaries
  if use_mask is not None:
    filter.UseMask = use_mask
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  filter.execute()
  return filter.ErrorCode

def principal_component_analysis(data_container_array, selected_data_array_paths = None, pc_attribute_matrix_name = None, pc_eigenvalues_name = None, pc_eigenvectors_name = None, matrix_approach = None, project_data_space = None, number_of_dimensions_for_projection = None, projected_data_space_array_path = None, observer = None) -> int:
  """Pythonic interface to PrincipalComponentAnalysis Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    pc_attribute_matrix_name (QString): Sets the "PCAttributeMatrixName" filter property
    pc_eigenvalues_name (QString): Sets the "PCEigenvaluesName" filter property
    pc_eigenvectors_name (QString): Sets the "PCEigenvectorsName" filter property
    matrix_approach (int): Sets the "MatrixApproach" filter property
    project_data_space (bool): Sets the "ProjectDataSpace" filter property
    number_of_dimensions_for_projection (int): Sets the "NumberOfDimensionsForProjection" filter property
    projected_data_space_array_path (DataArrayPath): Sets the "ProjectedDataSpaceArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.PrincipalComponentAnalysis()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  if pc_attribute_matrix_name is not None:
    filter.PCAttributeMatrixName = pc_attribute_matrix_name
  if pc_eigenvalues_name is not None:
    filter.PCEigenvaluesName = pc_eigenvalues_name
  if pc_eigenvectors_name is not None:
    filter.PCEigenvectorsName = pc_eigenvectors_name
  if matrix_approach is not None:
    filter.MatrixApproach = matrix_approach
  if project_data_space is not None:
    filter.ProjectDataSpace = project_data_space
  if number_of_dimensions_for_projection is not None:
    filter.NumberOfDimensionsForProjection = number_of_dimensions_for_projection
  if projected_data_space_array_path is not None:
    filter.ProjectedDataSpaceArrayPath = projected_data_space_array_path
  filter.execute()
  return filter.ErrorCode

def remove_flagged_vertices(data_container_array, vertex_geometry = None, mask_array_path = None, reduced_vertex_geometry = None, observer = None) -> int:
  """Pythonic interface to RemoveFlaggedVertices Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    vertex_geometry (DataArrayPath): Sets the "VertexGeometry" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    reduced_vertex_geometry (QString): Sets the "ReducedVertexGeometry" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.RemoveFlaggedVertices()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if vertex_geometry is not None:
    filter.VertexGeometry = vertex_geometry
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if reduced_vertex_geometry is not None:
    filter.ReducedVertexGeometry = reduced_vertex_geometry
  filter.execute()
  return filter.ErrorCode

def silhouette(data_container_array, selected_array_path = None, use_mask = None, mask_array_path = None, feature_ids_array_path = None, silhouette_array_path = None, distance_metric = None, observer = None) -> int:
  """Pythonic interface to Silhouette Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    silhouette_array_path (DataArrayPath): Sets the "SilhouetteArrayPath" filter property
    distance_metric (int): Sets the "DistanceMetric" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.Silhouette()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if silhouette_array_path is not None:
    filter.SilhouetteArrayPath = silhouette_array_path
  if distance_metric is not None:
    filter.DistanceMetric = distance_metric
  filter.execute()
  return filter.ErrorCode

def wave_front_object_file_writer(data_container_array, output_wave_front_file = None, triangle_geometry = None, observer = None) -> int:
  """Pythonic interface to WaveFrontObjectFileWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_wave_front_file (QString): Sets the "OutputWaveFrontFile" filter property
    triangle_geometry (DataArrayPath): Sets the "TriangleGeometry" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.WaveFrontObjectFileWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_wave_front_file is not None:
    filter.OutputWaveFrontFile = output_wave_front_file
  if triangle_geometry is not None:
    filter.TriangleGeometry = triangle_geometry
  filter.execute()
  return filter.ErrorCode

def robust_automatic_threshold(data_container_array, input_array_path = None, feature_ids_array_path = None, gradient_magnitude_array_path = None, observer = None) -> int:
  """Pythonic interface to RobustAutomaticThreshold Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_array_path (DataArrayPath): Sets the "InputArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    gradient_magnitude_array_path (DataArrayPath): Sets the "GradientMagnitudeArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.RobustAutomaticThreshold()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_array_path is not None:
    filter.InputArrayPath = input_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if gradient_magnitude_array_path is not None:
    filter.GradientMagnitudeArrayPath = gradient_magnitude_array_path
  filter.execute()
  return filter.ErrorCode

def align_geometries(data_container_array, moving_geometry = None, target_geometry = None, alignment_type = None, observer = None) -> int:
  """Pythonic interface to AlignGeometries Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    moving_geometry (DataArrayPath): Sets the "MovingGeometry" filter property
    target_geometry (DataArrayPath): Sets the "TargetGeometry" filter property
    alignment_type (int): Sets the "AlignmentType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.AlignGeometries()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if moving_geometry is not None:
    filter.MovingGeometry = moving_geometry
  if target_geometry is not None:
    filter.TargetGeometry = target_geometry
  if alignment_type is not None:
    filter.AlignmentType = alignment_type
  filter.execute()
  return filter.ErrorCode

def find_neighbor_list_statistics(data_container_array, find_length = None, find_min = None, find_max = None, find_mean = None, find_median = None, find_std_deviation = None, find_summation = None, destination_attribute_matrix = None, length_array_name = None, minimum_array_name = None, maximum_array_name = None, mean_array_name = None, median_array_name = None, std_deviation_array_name = None, summation_array_name = None, selected_array_path = None, observer = None) -> int:
  """Pythonic interface to FindNeighborListStatistics Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    find_length (bool): Sets the "FindLength" filter property
    find_min (bool): Sets the "FindMin" filter property
    find_max (bool): Sets the "FindMax" filter property
    find_mean (bool): Sets the "FindMean" filter property
    find_median (bool): Sets the "FindMedian" filter property
    find_std_deviation (bool): Sets the "FindStdDeviation" filter property
    find_summation (bool): Sets the "FindSummation" filter property
    destination_attribute_matrix (DataArrayPath): Sets the "DestinationAttributeMatrix" filter property
    length_array_name (QString): Sets the "LengthArrayName" filter property
    minimum_array_name (QString): Sets the "MinimumArrayName" filter property
    maximum_array_name (QString): Sets the "MaximumArrayName" filter property
    mean_array_name (QString): Sets the "MeanArrayName" filter property
    median_array_name (QString): Sets the "MedianArrayName" filter property
    std_deviation_array_name (QString): Sets the "StdDeviationArrayName" filter property
    summation_array_name (QString): Sets the "SummationArrayName" filter property
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.FindNeighborListStatistics()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if find_length is not None:
    filter.FindLength = find_length
  if find_min is not None:
    filter.FindMin = find_min
  if find_max is not None:
    filter.FindMax = find_max
  if find_mean is not None:
    filter.FindMean = find_mean
  if find_median is not None:
    filter.FindMedian = find_median
  if find_std_deviation is not None:
    filter.FindStdDeviation = find_std_deviation
  if find_summation is not None:
    filter.FindSummation = find_summation
  if destination_attribute_matrix is not None:
    filter.DestinationAttributeMatrix = destination_attribute_matrix
  if length_array_name is not None:
    filter.LengthArrayName = length_array_name
  if minimum_array_name is not None:
    filter.MinimumArrayName = minimum_array_name
  if maximum_array_name is not None:
    filter.MaximumArrayName = maximum_array_name
  if mean_array_name is not None:
    filter.MeanArrayName = mean_array_name
  if median_array_name is not None:
    filter.MedianArrayName = median_array_name
  if std_deviation_array_name is not None:
    filter.StdDeviationArrayName = std_deviation_array_name
  if summation_array_name is not None:
    filter.SummationArrayName = summation_array_name
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  filter.execute()
  return filter.ErrorCode

def interpolate_point_cloud_to_regular_grid(data_container_array, data_container_name = None, arrays_to_interpolate = None, arrays_to_copy = None, voxel_indices_array_path = None, interpolated_data_container_name = None, interpolated_attribute_matrix_name = None, interpolation_technique = None, kernel_size = None, sigmas = None, use_mask = None, mask_array_path = None, store_kernel_distances = None, kernel_distances_array_name = None, interpolated_suffix = None, copy_suffix = None, observer = None) -> int:
  """Pythonic interface to InterpolatePointCloudToRegularGrid Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    arrays_to_interpolate (std::vector<DataArrayPath>): Sets the "ArraysToInterpolate" filter property
    arrays_to_copy (std::vector<DataArrayPath>): Sets the "ArraysToCopy" filter property
    voxel_indices_array_path (DataArrayPath): Sets the "VoxelIndicesArrayPath" filter property
    interpolated_data_container_name (DataArrayPath): Sets the "InterpolatedDataContainerName" filter property
    interpolated_attribute_matrix_name (QString): Sets the "InterpolatedAttributeMatrixName" filter property
    interpolation_technique (int): Sets the "InterpolationTechnique" filter property
    kernel_size (FloatVec3Type): Sets the "KernelSize" filter property
    sigmas (FloatVec3Type): Sets the "Sigmas" filter property
    use_mask (bool): Sets the "UseMask" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    store_kernel_distances (bool): Sets the "StoreKernelDistances" filter property
    kernel_distances_array_name (QString): Sets the "KernelDistancesArrayName" filter property
    interpolated_suffix (QString): Sets the "InterpolatedSuffix" filter property
    copy_suffix (QString): Sets the "CopySuffix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.InterpolatePointCloudToRegularGrid()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if arrays_to_interpolate is not None:
    filter.ArraysToInterpolate = arrays_to_interpolate
  if arrays_to_copy is not None:
    filter.ArraysToCopy = arrays_to_copy
  if voxel_indices_array_path is not None:
    filter.VoxelIndicesArrayPath = voxel_indices_array_path
  if interpolated_data_container_name is not None:
    filter.InterpolatedDataContainerName = interpolated_data_container_name
  if interpolated_attribute_matrix_name is not None:
    filter.InterpolatedAttributeMatrixName = interpolated_attribute_matrix_name
  if interpolation_technique is not None:
    filter.InterpolationTechnique = interpolation_technique
  if kernel_size is not None:
    filter.KernelSize = kernel_size
  if sigmas is not None:
    filter.Sigmas = sigmas
  if use_mask is not None:
    filter.UseMask = use_mask
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if store_kernel_distances is not None:
    filter.StoreKernelDistances = store_kernel_distances
  if kernel_distances_array_name is not None:
    filter.KernelDistancesArrayName = kernel_distances_array_name
  if interpolated_suffix is not None:
    filter.InterpolatedSuffix = interpolated_suffix
  if copy_suffix is not None:
    filter.CopySuffix = copy_suffix
  filter.execute()
  return filter.ErrorCode

def map_point_cloud_to_regular_grid(data_container_array, data_container_name = None, created_image_data_container_name = None, image_data_container_path = None, voxel_indices_array_path = None, grid_dimensions = None, use_mask = None, sampling_grid_type = None, mask_array_path = None, observer = None) -> int:
  """Pythonic interface to MapPointCloudToRegularGrid Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    created_image_data_container_name (DataArrayPath): Sets the "CreatedImageDataContainerName" filter property
    image_data_container_path (DataArrayPath): Sets the "ImageDataContainerPath" filter property
    voxel_indices_array_path (DataArrayPath): Sets the "VoxelIndicesArrayPath" filter property
    grid_dimensions (IntVec3Type): Sets the "GridDimensions" filter property
    use_mask (bool): Sets the "UseMask" filter property
    sampling_grid_type (int): Sets the "SamplingGridType" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.MapPointCloudToRegularGrid()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if created_image_data_container_name is not None:
    filter.CreatedImageDataContainerName = created_image_data_container_name
  if image_data_container_path is not None:
    filter.ImageDataContainerPath = image_data_container_path
  if voxel_indices_array_path is not None:
    filter.VoxelIndicesArrayPath = voxel_indices_array_path
  if grid_dimensions is not None:
    filter.GridDimensions = grid_dimensions
  if use_mask is not None:
    filter.UseMask = use_mask
  if sampling_grid_type is not None:
    filter.SamplingGridType = sampling_grid_type
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  filter.execute()
  return filter.ErrorCode

def read_binary_ct_north_star(data_container_array, input_header_file = None, data_container_name = None, cell_attribute_matrix_name = None, density_array_name = None, length_unit = None, import_subvolume = None, start_voxel_coord = None, end_voxel_coord = None, volume_description = None, data_file_info = None, imported_volume_description = None, observer = None) -> int:
  """Pythonic interface to ReadBinaryCTNorthStar Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_header_file (QString): Sets the "InputHeaderFile" filter property
    data_container_name (QString): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    density_array_name (QString): Sets the "DensityArrayName" filter property
    length_unit (int32_t): Sets the "LengthUnit" filter property
    import_subvolume (bool): Sets the "ImportSubvolume" filter property
    start_voxel_coord (IntVec3Type): Sets the "StartVoxelCoord" filter property
    end_voxel_coord (IntVec3Type): Sets the "EndVoxelCoord" filter property
    volume_description (QString): Sets the "VolumeDescription" filter property
    data_file_info (QString): Sets the "DataFileInfo" filter property
    imported_volume_description (QString): Sets the "ImportedVolumeDescription" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ReadBinaryCTNorthStar()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_header_file is not None:
    filter.InputHeaderFile = input_header_file
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if density_array_name is not None:
    filter.DensityArrayName = density_array_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if import_subvolume is not None:
    filter.ImportSubvolume = import_subvolume
  if start_voxel_coord is not None:
    filter.StartVoxelCoord = start_voxel_coord
  if end_voxel_coord is not None:
    filter.EndVoxelCoord = end_voxel_coord
  if volume_description is not None:
    filter.VolumeDescription = volume_description
  if data_file_info is not None:
    filter.DataFileInfo = data_file_info
  if imported_volume_description is not None:
    filter.ImportedVolumeDescription = imported_volume_description
  filter.execute()
  return filter.ErrorCode

def slice_triangle_geometry(data_container_array, cad_data_container_name = None, slice_data_container_name = None, edge_attribute_matrix_name = None, slice_attribute_matrix_name = None, slice_id_array_name = None, have_region_ids = None, region_id_array_path = None, slice_direction = None, slice_resolution = None, zstart = None, zend = None, slice_range = None, observer = None) -> int:
  """Pythonic interface to SliceTriangleGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cad_data_container_name (DataArrayPath): Sets the "CADDataContainerName" filter property
    slice_data_container_name (QString): Sets the "SliceDataContainerName" filter property
    edge_attribute_matrix_name (QString): Sets the "EdgeAttributeMatrixName" filter property
    slice_attribute_matrix_name (QString): Sets the "SliceAttributeMatrixName" filter property
    slice_id_array_name (QString): Sets the "SliceIdArrayName" filter property
    have_region_ids (bool): Sets the "HaveRegionIds" filter property
    region_id_array_path (DataArrayPath): Sets the "RegionIdArrayPath" filter property
    slice_direction (FloatVec3Type): Sets the "SliceDirection" filter property
    slice_resolution (float): Sets the "SliceResolution" filter property
    zstart (float): Sets the "Zstart" filter property
    zend (float): Sets the "Zend" filter property
    slice_range (int): Sets the "SliceRange" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.SliceTriangleGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cad_data_container_name is not None:
    filter.CADDataContainerName = cad_data_container_name
  if slice_data_container_name is not None:
    filter.SliceDataContainerName = slice_data_container_name
  if edge_attribute_matrix_name is not None:
    filter.EdgeAttributeMatrixName = edge_attribute_matrix_name
  if slice_attribute_matrix_name is not None:
    filter.SliceAttributeMatrixName = slice_attribute_matrix_name
  if slice_id_array_name is not None:
    filter.SliceIdArrayName = slice_id_array_name
  if have_region_ids is not None:
    filter.HaveRegionIds = have_region_ids
  if region_id_array_path is not None:
    filter.RegionIdArrayPath = region_id_array_path
  if slice_direction is not None:
    filter.SliceDirection = slice_direction
  if slice_resolution is not None:
    filter.SliceResolution = slice_resolution
  if zstart is not None:
    filter.Zstart = zstart
  if zend is not None:
    filter.Zend = zend
  if slice_range is not None:
    filter.SliceRange = slice_range
  filter.execute()
  return filter.ErrorCode

def steiner_compact(data_container_array, vtk_output = None, vtk_file_name = None, txt_output = None, txt_file_name = None, feature_ids_array_path = None, cell_phases_array_path = None, plane = None, sites = None, observer = None) -> int:
  """Pythonic interface to SteinerCompact Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    vtk_output (bool): Sets the "VtkOutput" filter property
    vtk_file_name (QString): Sets the "VtkFileName" filter property
    txt_output (bool): Sets the "TxtOutput" filter property
    txt_file_name (QString): Sets the "TxtFileName" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    plane (int): Sets the "Plane" filter property
    sites (int): Sets the "Sites" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.SteinerCompact()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if vtk_output is not None:
    filter.VtkOutput = vtk_output
  if vtk_file_name is not None:
    filter.VtkFileName = vtk_file_name
  if txt_output is not None:
    filter.TxtOutput = txt_output
  if txt_file_name is not None:
    filter.TxtFileName = txt_file_name
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if plane is not None:
    filter.Plane = plane
  if sites is not None:
    filter.Sites = sites
  filter.execute()
  return filter.ErrorCode

def read_mic_data(data_container_array, data_container_name = None, cell_ensemble_attribute_matrix_name = None, cell_attribute_matrix_name = None, file_was_read = None, input_file = None, observer = None) -> int:
  """Pythonic interface to ReadMicData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    file_was_read (bool): Sets the "FileWasRead" filter property
    input_file (QString): Sets the "InputFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ReadMicData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if file_was_read is not None:
    filter.FileWasRead = file_was_read
  if input_file is not None:
    filter.InputFile = input_file
  filter.execute()
  return filter.ErrorCode

def tesselate_far_field_grains(data_container_array, output_cell_attribute_matrix_name = None, feature_ids_array_name = None, cell_phases_array_name = None, slab_id_array_name = None, feature_phases_array_name = None, feature_euler_angles_array_name = None, elastic_strains_array_name = None, centroids_array_name = None, volumes_array_name = None, axis_lengths_array_name = None, axis_euler_angles_array_name = None, omega3s_array_name = None, equivalent_diameters_array_name = None, crystal_structures_array_name = None, mask_array_path = None, feature_input_file_list_info = None, observer = None) -> int:
  """Pythonic interface to TesselateFarFieldGrains Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_cell_attribute_matrix_name (DataArrayPath): Sets the "OutputCellAttributeMatrixName" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    cell_phases_array_name (QString): Sets the "CellPhasesArrayName" filter property
    slab_id_array_name (QString): Sets the "SlabIdArrayName" filter property
    feature_phases_array_name (QString): Sets the "FeaturePhasesArrayName" filter property
    feature_euler_angles_array_name (QString): Sets the "FeatureEulerAnglesArrayName" filter property
    elastic_strains_array_name (QString): Sets the "ElasticStrainsArrayName" filter property
    centroids_array_name (QString): Sets the "CentroidsArrayName" filter property
    volumes_array_name (QString): Sets the "VolumesArrayName" filter property
    axis_lengths_array_name (QString): Sets the "AxisLengthsArrayName" filter property
    axis_euler_angles_array_name (QString): Sets the "AxisEulerAnglesArrayName" filter property
    omega3s_array_name (QString): Sets the "Omega3sArrayName" filter property
    equivalent_diameters_array_name (QString): Sets the "EquivalentDiametersArrayName" filter property
    crystal_structures_array_name (QString): Sets the "CrystalStructuresArrayName" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    feature_input_file_list_info (StackFileListInfo): Sets the "FeatureInputFileListInfo" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.TesselateFarFieldGrains()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_cell_attribute_matrix_name is not None:
    filter.OutputCellAttributeMatrixName = output_cell_attribute_matrix_name
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if cell_phases_array_name is not None:
    filter.CellPhasesArrayName = cell_phases_array_name
  if slab_id_array_name is not None:
    filter.SlabIdArrayName = slab_id_array_name
  if feature_phases_array_name is not None:
    filter.FeaturePhasesArrayName = feature_phases_array_name
  if feature_euler_angles_array_name is not None:
    filter.FeatureEulerAnglesArrayName = feature_euler_angles_array_name
  if elastic_strains_array_name is not None:
    filter.ElasticStrainsArrayName = elastic_strains_array_name
  if centroids_array_name is not None:
    filter.CentroidsArrayName = centroids_array_name
  if volumes_array_name is not None:
    filter.VolumesArrayName = volumes_array_name
  if axis_lengths_array_name is not None:
    filter.AxisLengthsArrayName = axis_lengths_array_name
  if axis_euler_angles_array_name is not None:
    filter.AxisEulerAnglesArrayName = axis_euler_angles_array_name
  if omega3s_array_name is not None:
    filter.Omega3sArrayName = omega3s_array_name
  if equivalent_diameters_array_name is not None:
    filter.EquivalentDiametersArrayName = equivalent_diameters_array_name
  if crystal_structures_array_name is not None:
    filter.CrystalStructuresArrayName = crystal_structures_array_name
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if feature_input_file_list_info is not None:
    filter.FeatureInputFileListInfo = feature_input_file_list_info
  filter.execute()
  return filter.ErrorCode

def ffthdf_writer_filter(data_container_array, output_file = None, write_eigenstrains = None, eigenstrains_output_file = None, feature_ids_array_path = None, cell_phases_array_path = None, cell_euler_angles_array_path = None, cell_eigenstrains_array_path = None, observer = None) -> int:
  """Pythonic interface to FFTHDFWriterFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    write_eigenstrains (bool): Sets the "WriteEigenstrains" filter property
    eigenstrains_output_file (QString): Sets the "EigenstrainsOutputFile" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    cell_eigenstrains_array_path (DataArrayPath): Sets the "CellEigenstrainsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.FFTHDFWriterFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_eigenstrains is not None:
    filter.WriteEigenstrains = write_eigenstrains
  if eigenstrains_output_file is not None:
    filter.EigenstrainsOutputFile = eigenstrains_output_file
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if cell_eigenstrains_array_path is not None:
    filter.CellEigenstrainsArrayPath = cell_eigenstrains_array_path
  filter.execute()
  return filter.ErrorCode

def import_massif_data(data_container_array, massif_input_file_path = None, file_prefix = None, step_number = None, observer = None) -> int:
  """Pythonic interface to ImportMASSIFData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    massif_input_file_path (QString): Sets the "MassifInputFilePath" filter property
    file_prefix (QString): Sets the "FilePrefix" filter property
    step_number (int): Sets the "StepNumber" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ImportMASSIFData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if massif_input_file_path is not None:
    filter.MassifInputFilePath = massif_input_file_path
  if file_prefix is not None:
    filter.FilePrefix = file_prefix
  if step_number is not None:
    filter.StepNumber = step_number
  filter.execute()
  return filter.ErrorCode

def local_dislocation_density_calculator(data_container_array, edge_data_container_name = None, burgers_vectors_array_path = None, slip_plane_normals_array_path = None, cell_size = None, output_data_container_name = None, output_attribute_matrix_name = None, output_array_name = None, dominant_system_array_name = None, observer = None) -> int:
  """Pythonic interface to LocalDislocationDensityCalculator Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    edge_data_container_name (DataArrayPath): Sets the "EdgeDataContainerName" filter property
    burgers_vectors_array_path (DataArrayPath): Sets the "BurgersVectorsArrayPath" filter property
    slip_plane_normals_array_path (DataArrayPath): Sets the "SlipPlaneNormalsArrayPath" filter property
    cell_size (FloatVec3Type): Sets the "CellSize" filter property
    output_data_container_name (DataArrayPath): Sets the "OutputDataContainerName" filter property
    output_attribute_matrix_name (QString): Sets the "OutputAttributeMatrixName" filter property
    output_array_name (QString): Sets the "OutputArrayName" filter property
    dominant_system_array_name (QString): Sets the "DominantSystemArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.LocalDislocationDensityCalculator()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if edge_data_container_name is not None:
    filter.EdgeDataContainerName = edge_data_container_name
  if burgers_vectors_array_path is not None:
    filter.BurgersVectorsArrayPath = burgers_vectors_array_path
  if slip_plane_normals_array_path is not None:
    filter.SlipPlaneNormalsArrayPath = slip_plane_normals_array_path
  if cell_size is not None:
    filter.CellSize = cell_size
  if output_data_container_name is not None:
    filter.OutputDataContainerName = output_data_container_name
  if output_attribute_matrix_name is not None:
    filter.OutputAttributeMatrixName = output_attribute_matrix_name
  if output_array_name is not None:
    filter.OutputArrayName = output_array_name
  if dominant_system_array_name is not None:
    filter.DominantSystemArrayName = dominant_system_array_name
  filter.execute()
  return filter.ErrorCode

def identify_dislocation_segments(data_container_array, burgers_vectors_array_path = None, slip_plane_normals_array_path = None, dislocation_ids_array_name = None, active_array_name = None, observer = None) -> int:
  """Pythonic interface to IdentifyDislocationSegments Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    burgers_vectors_array_path (DataArrayPath): Sets the "BurgersVectorsArrayPath" filter property
    slip_plane_normals_array_path (DataArrayPath): Sets the "SlipPlaneNormalsArrayPath" filter property
    dislocation_ids_array_name (QString): Sets the "DislocationIdsArrayName" filter property
    active_array_name (QString): Sets the "ActiveArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.IdentifyDislocationSegments()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if burgers_vectors_array_path is not None:
    filter.BurgersVectorsArrayPath = burgers_vectors_array_path
  if slip_plane_normals_array_path is not None:
    filter.SlipPlaneNormalsArrayPath = slip_plane_normals_array_path
  if dislocation_ids_array_name is not None:
    filter.DislocationIdsArrayName = dislocation_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  filter.execute()
  return filter.ErrorCode

def discretize_dd_domain(data_container_array, edge_data_container_name = None, cell_size = None, output_data_container_name = None, output_attribute_matrix_name = None, output_array_name = None, observer = None) -> int:
  """Pythonic interface to DiscretizeDDDomain Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    edge_data_container_name (DataArrayPath): Sets the "EdgeDataContainerName" filter property
    cell_size (FloatVec3Type): Sets the "CellSize" filter property
    output_data_container_name (DataArrayPath): Sets the "OutputDataContainerName" filter property
    output_attribute_matrix_name (QString): Sets the "OutputAttributeMatrixName" filter property
    output_array_name (QString): Sets the "OutputArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.DiscretizeDDDomain()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if edge_data_container_name is not None:
    filter.EdgeDataContainerName = edge_data_container_name
  if cell_size is not None:
    filter.CellSize = cell_size
  if output_data_container_name is not None:
    filter.OutputDataContainerName = output_data_container_name
  if output_attribute_matrix_name is not None:
    filter.OutputAttributeMatrixName = output_attribute_matrix_name
  if output_array_name is not None:
    filter.OutputArrayName = output_array_name
  filter.execute()
  return filter.ErrorCode

def para_dis_reader(data_container_array, edge_data_container_name = None, vertex_attribute_matrix_name = None, edge_attribute_matrix_name = None, input_file = None, burgers_vector = None, number_of_arms_array_name = None, node_constraints_array_name = None, burgers_vectors_array_name = None, slip_plane_normals_array_name = None, domain_bounds_array_name = None, observer = None) -> int:
  """Pythonic interface to ParaDisReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    edge_data_container_name (DataArrayPath): Sets the "EdgeDataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    edge_attribute_matrix_name (QString): Sets the "EdgeAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    burgers_vector (float): Sets the "BurgersVector" filter property
    number_of_arms_array_name (QString): Sets the "NumberOfArmsArrayName" filter property
    node_constraints_array_name (QString): Sets the "NodeConstraintsArrayName" filter property
    burgers_vectors_array_name (QString): Sets the "BurgersVectorsArrayName" filter property
    slip_plane_normals_array_name (QString): Sets the "SlipPlaneNormalsArrayName" filter property
    domain_bounds_array_name (QString): Sets the "DomainBoundsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ParaDisReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if edge_data_container_name is not None:
    filter.EdgeDataContainerName = edge_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if edge_attribute_matrix_name is not None:
    filter.EdgeAttributeMatrixName = edge_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if burgers_vector is not None:
    filter.BurgersVector = burgers_vector
  if number_of_arms_array_name is not None:
    filter.NumberOfArmsArrayName = number_of_arms_array_name
  if node_constraints_array_name is not None:
    filter.NodeConstraintsArrayName = node_constraints_array_name
  if burgers_vectors_array_name is not None:
    filter.BurgersVectorsArrayName = burgers_vectors_array_name
  if slip_plane_normals_array_name is not None:
    filter.SlipPlaneNormalsArrayName = slip_plane_normals_array_name
  if domain_bounds_array_name is not None:
    filter.DomainBoundsArrayName = domain_bounds_array_name
  filter.execute()
  return filter.ErrorCode

def find_csl_boundaries(data_container_array, csl = None, axis_tolerance = None, angle_tolerance = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_csl_boundary_array_name = None, surface_mesh_csl_boundary_incoherence_array_name = None, observer = None) -> int:
  """Pythonic interface to FindCSLBoundaries Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    csl (float): Sets the "CSL" filter property
    axis_tolerance (float): Sets the "AxisTolerance" filter property
    angle_tolerance (float): Sets the "AngleTolerance" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    surface_mesh_csl_boundary_array_name (QString): Sets the "SurfaceMeshCSLBoundaryArrayName" filter property
    surface_mesh_csl_boundary_incoherence_array_name (QString): Sets the "SurfaceMeshCSLBoundaryIncoherenceArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.FindCSLBoundaries()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if csl is not None:
    filter.CSL = csl
  if axis_tolerance is not None:
    filter.AxisTolerance = axis_tolerance
  if angle_tolerance is not None:
    filter.AngleTolerance = angle_tolerance
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_csl_boundary_array_name is not None:
    filter.SurfaceMeshCSLBoundaryArrayName = surface_mesh_csl_boundary_array_name
  if surface_mesh_csl_boundary_incoherence_array_name is not None:
    filter.SurfaceMeshCSLBoundaryIncoherenceArrayName = surface_mesh_csl_boundary_incoherence_array_name
  filter.execute()
  return filter.ErrorCode

def insert_transformation_phases(data_container_array, parent_phase = None, trans_crystal_struct = None, transformation_phase_misorientation = None, transformation_phase_habit_plane = None, define_habit_plane = None, use_all_variants = None, coherent_frac = None, transformation_phase_thickness = None, num_transformation_phases_per_feature = None, peninsula_frac = None, stats_gen_cell_ensemble_attribute_matrix_path = None, cell_feature_attribute_matrix_name = None, feature_ids_array_path = None, cell_euler_angles_array_path = None, cell_phases_array_path = None, avg_quats_array_path = None, centroids_array_path = None, equivalent_diameters_array_path = None, feature_euler_angles_array_path = None, feature_phases_array_path = None, feature_parent_ids_array_name = None, num_features_per_parent_array_path = None, crystal_structures_array_path = None, phase_types_array_path = None, shape_types_array_path = None, num_features_array_path = None, observer = None) -> int:
  """Pythonic interface to InsertTransformationPhases Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    parent_phase (int): Sets the "ParentPhase" filter property
    trans_crystal_struct (int): Sets the "TransCrystalStruct" filter property
    transformation_phase_misorientation (float): Sets the "TransformationPhaseMisorientation" filter property
    transformation_phase_habit_plane (FloatVec3Type): Sets the "TransformationPhaseHabitPlane" filter property
    define_habit_plane (bool): Sets the "DefineHabitPlane" filter property
    use_all_variants (bool): Sets the "UseAllVariants" filter property
    coherent_frac (float): Sets the "CoherentFrac" filter property
    transformation_phase_thickness (float): Sets the "TransformationPhaseThickness" filter property
    num_transformation_phases_per_feature (int): Sets the "NumTransformationPhasesPerFeature" filter property
    peninsula_frac (float): Sets the "PeninsulaFrac" filter property
    stats_gen_cell_ensemble_attribute_matrix_path (DataArrayPath): Sets the "StatsGenCellEnsembleAttributeMatrixPath" filter property
    cell_feature_attribute_matrix_name (DataArrayPath): Sets the "CellFeatureAttributeMatrixName" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    centroids_array_path (DataArrayPath): Sets the "CentroidsArrayPath" filter property
    equivalent_diameters_array_path (DataArrayPath): Sets the "EquivalentDiametersArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    feature_parent_ids_array_name (QString): Sets the "FeatureParentIdsArrayName" filter property
    num_features_per_parent_array_path (DataArrayPath): Sets the "NumFeaturesPerParentArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    phase_types_array_path (DataArrayPath): Sets the "PhaseTypesArrayPath" filter property
    shape_types_array_path (DataArrayPath): Sets the "ShapeTypesArrayPath" filter property
    num_features_array_path (DataArrayPath): Sets the "NumFeaturesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.InsertTransformationPhases()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if parent_phase is not None:
    filter.ParentPhase = parent_phase
  if trans_crystal_struct is not None:
    filter.TransCrystalStruct = trans_crystal_struct
  if transformation_phase_misorientation is not None:
    filter.TransformationPhaseMisorientation = transformation_phase_misorientation
  if transformation_phase_habit_plane is not None:
    filter.TransformationPhaseHabitPlane = transformation_phase_habit_plane
  if define_habit_plane is not None:
    filter.DefineHabitPlane = define_habit_plane
  if use_all_variants is not None:
    filter.UseAllVariants = use_all_variants
  if coherent_frac is not None:
    filter.CoherentFrac = coherent_frac
  if transformation_phase_thickness is not None:
    filter.TransformationPhaseThickness = transformation_phase_thickness
  if num_transformation_phases_per_feature is not None:
    filter.NumTransformationPhasesPerFeature = num_transformation_phases_per_feature
  if peninsula_frac is not None:
    filter.PeninsulaFrac = peninsula_frac
  if stats_gen_cell_ensemble_attribute_matrix_path is not None:
    filter.StatsGenCellEnsembleAttributeMatrixPath = stats_gen_cell_ensemble_attribute_matrix_path
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if centroids_array_path is not None:
    filter.CentroidsArrayPath = centroids_array_path
  if equivalent_diameters_array_path is not None:
    filter.EquivalentDiametersArrayPath = equivalent_diameters_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if feature_parent_ids_array_name is not None:
    filter.FeatureParentIdsArrayName = feature_parent_ids_array_name
  if num_features_per_parent_array_path is not None:
    filter.NumFeaturesPerParentArrayPath = num_features_per_parent_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if phase_types_array_path is not None:
    filter.PhaseTypesArrayPath = phase_types_array_path
  if shape_types_array_path is not None:
    filter.ShapeTypesArrayPath = shape_types_array_path
  if num_features_array_path is not None:
    filter.NumFeaturesArrayPath = num_features_array_path
  filter.execute()
  return filter.ErrorCode

def generate_feature_i_dsby_bounding_boxes(data_container_array, feature_i_ds_array_path = None, feature_attribute_matrix_array_path = None, box_center_array_path = None, box_dimensions_array_path = None, box_feature_i_ds_array_path = None, observer = None) -> int:
  """Pythonic interface to GenerateFeatureIDsbyBoundingBoxes Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_i_ds_array_path (DataArrayPath): Sets the "FeatureIDsArrayPath" filter property
    feature_attribute_matrix_array_path (DataArrayPath): Sets the "FeatureAttributeMatrixArrayPath" filter property
    box_center_array_path (DataArrayPath): Sets the "BoxCenterArrayPath" filter property
    box_dimensions_array_path (DataArrayPath): Sets the "BoxDimensionsArrayPath" filter property
    box_feature_i_ds_array_path (DataArrayPath): Sets the "BoxFeatureIDsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.GenerateFeatureIDsbyBoundingBoxes()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_i_ds_array_path is not None:
    filter.FeatureIDsArrayPath = feature_i_ds_array_path
  if feature_attribute_matrix_array_path is not None:
    filter.FeatureAttributeMatrixArrayPath = feature_attribute_matrix_array_path
  if box_center_array_path is not None:
    filter.BoxCenterArrayPath = box_center_array_path
  if box_dimensions_array_path is not None:
    filter.BoxDimensionsArrayPath = box_dimensions_array_path
  if box_feature_i_ds_array_path is not None:
    filter.BoxFeatureIDsArrayPath = box_feature_i_ds_array_path
  filter.execute()
  return filter.ErrorCode

def generate_mask_from_simple_shapes(data_container_array, mask_array_path = None, centers_array_path = None, axes_length_array_path = None, box_dimensions_array_path = None, cylinder_radius_array_path = None, cylinder_height_array_path = None, mask_shape = None, observer = None) -> int:
  """Pythonic interface to GenerateMaskFromSimpleShapes Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    centers_array_path (DataArrayPath): Sets the "CentersArrayPath" filter property
    axes_length_array_path (DataArrayPath): Sets the "AxesLengthArrayPath" filter property
    box_dimensions_array_path (DataArrayPath): Sets the "BoxDimensionsArrayPath" filter property
    cylinder_radius_array_path (DataArrayPath): Sets the "CylinderRadiusArrayPath" filter property
    cylinder_height_array_path (DataArrayPath): Sets the "CylinderHeightArrayPath" filter property
    mask_shape (int): Sets the "MaskShape" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.GenerateMaskFromSimpleShapes()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if centers_array_path is not None:
    filter.CentersArrayPath = centers_array_path
  if axes_length_array_path is not None:
    filter.AxesLengthArrayPath = axes_length_array_path
  if box_dimensions_array_path is not None:
    filter.BoxDimensionsArrayPath = box_dimensions_array_path
  if cylinder_radius_array_path is not None:
    filter.CylinderRadiusArrayPath = cylinder_radius_array_path
  if cylinder_height_array_path is not None:
    filter.CylinderHeightArrayPath = cylinder_height_array_path
  if mask_shape is not None:
    filter.MaskShape = mask_shape
  filter.execute()
  return filter.ErrorCode

def create_arrayof_indices(data_container_array, index_array_path = None, observer = None) -> int:
  """Pythonic interface to CreateArrayofIndices Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    index_array_path (DataArrayPath): Sets the "IndexArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.CreateArrayofIndices()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if index_array_path is not None:
    filter.IndexArrayPath = index_array_path
  filter.execute()
  return filter.ErrorCode

def compute_feature_eigenstrains(data_container_array, poisson_ratio = None, use_ellipsoidal_grains = None, use_correctional_matrix = None, beta11 = None, beta22 = None, beta33 = None, beta23 = None, beta13 = None, beta12 = None, axis_lengths_array_path = None, axis_euler_angles_array_path = None, elastic_strains_array_path = None, eigenstrains_array_name = None, observer = None) -> int:
  """Pythonic interface to ComputeFeatureEigenstrains Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    poisson_ratio (float): Sets the "PoissonRatio" filter property
    use_ellipsoidal_grains (bool): Sets the "UseEllipsoidalGrains" filter property
    use_correctional_matrix (bool): Sets the "UseCorrectionalMatrix" filter property
    beta11 (float): Sets the "Beta11" filter property
    beta22 (float): Sets the "Beta22" filter property
    beta33 (float): Sets the "Beta33" filter property
    beta23 (float): Sets the "Beta23" filter property
    beta13 (float): Sets the "Beta13" filter property
    beta12 (float): Sets the "Beta12" filter property
    axis_lengths_array_path (DataArrayPath): Sets the "AxisLengthsArrayPath" filter property
    axis_euler_angles_array_path (DataArrayPath): Sets the "AxisEulerAnglesArrayPath" filter property
    elastic_strains_array_path (DataArrayPath): Sets the "ElasticStrainsArrayPath" filter property
    eigenstrains_array_name (QString): Sets the "EigenstrainsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.ComputeFeatureEigenstrains()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if poisson_ratio is not None:
    filter.PoissonRatio = poisson_ratio
  if use_ellipsoidal_grains is not None:
    filter.UseEllipsoidalGrains = use_ellipsoidal_grains
  if use_correctional_matrix is not None:
    filter.UseCorrectionalMatrix = use_correctional_matrix
  if beta11 is not None:
    filter.Beta11 = beta11
  if beta22 is not None:
    filter.Beta22 = beta22
  if beta33 is not None:
    filter.Beta33 = beta33
  if beta23 is not None:
    filter.Beta23 = beta23
  if beta13 is not None:
    filter.Beta13 = beta13
  if beta12 is not None:
    filter.Beta12 = beta12
  if axis_lengths_array_path is not None:
    filter.AxisLengthsArrayPath = axis_lengths_array_path
  if axis_euler_angles_array_path is not None:
    filter.AxisEulerAnglesArrayPath = axis_euler_angles_array_path
  if elastic_strains_array_path is not None:
    filter.ElasticStrainsArrayPath = elastic_strains_array_path
  if eigenstrains_array_name is not None:
    filter.EigenstrainsArrayName = eigenstrains_array_name
  filter.execute()
  return filter.ErrorCode

def adaptive_alignment_feature(data_container_array, good_voxels_array_path = None, observer = None) -> int:
  """Pythonic interface to AdaptiveAlignmentFeature Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.AdaptiveAlignmentFeature()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  filter.execute()
  return filter.ErrorCode

def adaptive_alignment_misorientation(data_container_array, misorientation_tolerance = None, use_good_voxels = None, quats_array_path = None, cell_phases_array_path = None, good_voxels_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """Pythonic interface to AdaptiveAlignmentMisorientation Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.AdaptiveAlignmentMisorientation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def adaptive_alignment_mutual_information(data_container_array, misorientation_tolerance = None, use_good_voxels = None, quats_array_path = None, cell_phases_array_path = None, good_voxels_array_path = None, crystal_structures_array_path = None, global_correction = None, image_data_array_path = None, observer = None) -> int:
  """Pythonic interface to AdaptiveAlignmentMutualInformation Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    global_correction (int): Sets the "GlobalCorrection" filter property
    image_data_array_path (DataArrayPath): Sets the "ImageDataArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = dream3dreview.AdaptiveAlignmentMutualInformation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if global_correction is not None:
    filter.GlobalCorrection = global_correction
  if image_data_array_path is not None:
    filter.ImageDataArrayPath = image_data_array_path
  filter.execute()
  return filter.ErrorCode

